@@ -45,10 +45,11 @@ typedef enum
 
 typedef enum
 {
-  LID_TRIGGER_NOTHING,
+  LID_TRIGGER_DPMS,
   LID_TRIGGER_SUSPEND,
   LID_TRIGGER_HIBERNATE,
   LID_TRIGGER_LOCK_SCREEN,
+  LID_TRIGGER_NOTHING,
 } XfpmLidTriggerAction;
 
 typedef enum
@@ -82,15 +83,6 @@ typedef enum
   NEVER_SHOW_ICON
 } XfpmShowIcon;
 
-typedef enum
-{
-  PANEL_LABEL_NONE,
-  PANEL_LABEL_PERCENTAGE,
-  PANEL_LABEL_TIME,
-  PANEL_LABEL_PERCENTAGE_AND_TIME,
-  N_PANEL_LABELS
-} XfpmPanelLabel;
-
 G_END_DECLS
 
 #endif /* __XFPM_ENUM_GLIB_H */
