@@ -852,14 +852,8 @@ brightness_exponential_toggled_cb (GtkWidget *w, XfconfChannel *channel)
 void
 lock_screen_toggled_cb (GtkWidget *w, XfconfChannel *channel)
 {
-  XfconfChannel *session_channel = xfconf_channel_get ("xfce4-session");
   gboolean val = (gint) gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(w));
 
-  if ( !xfconf_channel_set_bool (session_channel, "/shutdown/LockScreen", val) )
-  {
-    g_critical ("Unable to set value for property %s\n", LOCK_SCREEN_ON_SLEEP);
-  }
-
   if ( !xfconf_channel_set_bool (channel, XFPM_PROPERTIES_PREFIX LOCK_SCREEN_ON_SLEEP, val) )
   {
     g_critical ("Unable to set value for property %s\n", LOCK_SCREEN_ON_SLEEP);
@@ -2283,10 +2277,13 @@ remove_device (const gchar *object_path)
                       COL_SIDEBAR_BATTERY_DEVICE, &device,
                       -1);
 
-  gtk_list_store_remove (list_store, iter);
-
   if (device)
+  {
     g_signal_handler_disconnect (device, signal_id);
+    g_object_unref (device);
+  }
+
+  gtk_list_store_remove (list_store, iter);
 
   /* If there are no devices left, hide the devices tab */
   if(!gtk_tree_model_get_iter_first (GTK_TREE_MODEL(list_store), iter))
@@ -2487,7 +2484,7 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean auth_suspend,
                                    CAIRO_GOBJECT_TYPE_SURFACE, /* COL_SIDEBAR_ICON */
                                    G_TYPE_STRING,   /* COL_SIDEBAR_NAME */
                                    G_TYPE_INT,      /* COL_SIDEBAR_INT */
-                                   G_TYPE_POINTER,  /* COL_SIDEBAR_BATTERY_DEVICE */
+                                   G_TYPE_OBJECT,   /* COL_SIDEBAR_BATTERY_DEVICE */
                                    G_TYPE_STRING,   /* COL_SIDEBAR_OBJECT_PATH */
                                    G_TYPE_ULONG,    /* COL_SIDEBAR_SIGNAL_ID */
                                    G_TYPE_POINTER   /* COL_SIDEBAR_VIEW */
