@@ -68,7 +68,7 @@ struct XfpmPolkitPrivate
 {
   GDBusConnection   *bus;
 
-#ifdef ENABLE_POLKIT
+#ifdef HAVE_POLKIT
   GDBusProxy        *proxy;
   GVariant          *subject;
   GVariant          *details;
@@ -88,7 +88,7 @@ static guint signals [LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (XfpmPolkit, xfpm_polkit, G_TYPE_OBJECT)
 
-#ifdef ENABLE_POLKIT
+#ifdef HAVE_POLKIT
 #if defined(__FreeBSD__)
 /**
  * Taken from polkitunixprocess.c code to get process start
@@ -225,17 +225,13 @@ out:
 
   return start_time;
 }
-#endif /*ENABLE_POLKIT*/
+#endif /*HAVE_POLKIT*/
 
 
-#ifdef ENABLE_POLKIT
-static gboolean
-xfpm_polkit_free_data (gpointer data)
+#ifdef HAVE_POLKIT
+static void
+xfpm_polkit_free_data (XfpmPolkit *polkit)
 {
-  XfpmPolkit *polkit;
-
-  polkit = XFPM_POLKIT (data);
-
   g_assert (polkit->priv->subject_valid);
 
   XFPM_DEBUG ("Destroying Polkit data");
@@ -248,6 +244,15 @@ xfpm_polkit_free_data (gpointer data)
 
   polkit->priv->destroy_id = 0;
   polkit->priv->subject_valid = FALSE;
+}
+
+static gboolean
+xfpm_polkit_free_data_cb (gpointer user_data)
+{
+  XfpmPolkit *polkit;
+
+  polkit = XFPM_POLKIT (user_data);
+  xfpm_polkit_free_data (polkit);
 
   return FALSE;
 }
@@ -301,18 +306,16 @@ xfpm_polkit_init_data (XfpmPolkit *polkit)
                                               &builder));
 
   /*Clean these data after 1 minute*/
-  polkit->priv->destroy_id = g_timeout_add_seconds (60,
-                                                    (GSourceFunc) xfpm_polkit_free_data,
-                                                    polkit);
+  polkit->priv->destroy_id = g_timeout_add_seconds (60, xfpm_polkit_free_data_cb, polkit);
 
   polkit->priv->subject_valid = TRUE;
 }
-#endif /*ENABLE_POLKIT*/
+#endif /*HAVE_POLKIT*/
 
 static gboolean
 xfpm_polkit_check_auth_intern (XfpmPolkit *polkit, const gchar *action_id)
 {
-#ifdef ENABLE_POLKIT
+#ifdef HAVE_POLKIT
   GError *error = NULL;
   gboolean is_authorized = FALSE;
   GVariant *var;
@@ -363,16 +366,23 @@ xfpm_polkit_check_auth_intern (XfpmPolkit *polkit, const gchar *action_id)
   XFPM_DEBUG ("Action=%s is authorized=%s", action_id, xfpm_bool_to_string (is_authorized));
 
   return is_authorized;
-#endif /*ENABLE_POLKIT*/
+#endif /*HAVE_POLKIT*/
   return TRUE;
 }
 
-#ifdef ENABLE_POLKIT
+#ifdef HAVE_POLKIT
 static void
-xfpm_polkit_changed_cb (GDBusProxy *proxy, XfpmPolkit *polkit)
+xfpm_polkit_changed_cb (GDBusProxy *proxy,
+                        gchar      *sender_name,
+                        gchar      *signal_name,
+                        GVariant   *parameters,
+                        XfpmPolkit *polkit)
 {
-  XFPM_DEBUG ("Auth changed");
-  g_signal_emit (G_OBJECT (polkit), signals [AUTH_CHANGED], 0);
+  if (g_strcmp0 (signal_name, "Changed") == 0)
+  {
+    XFPM_DEBUG ("Auth changed");
+    g_signal_emit (G_OBJECT (polkit), signals [AUTH_CHANGED], 0);
+  }
 }
 #endif
 
@@ -400,13 +410,13 @@ xfpm_polkit_init (XfpmPolkit *polkit)
 
   polkit->priv = xfpm_polkit_get_instance_private (polkit);
 
-#ifdef ENABLE_POLKIT
+#ifdef HAVE_POLKIT
   polkit->priv->destroy_id   = 0;
   polkit->priv->subject_valid   = FALSE;
   polkit->priv->proxy        = NULL;
   polkit->priv->subject      = NULL;
   polkit->priv->details      = NULL;
-#endif /*ENABLE_POLKIT*/
+#endif /*HAVE_POLKIT*/
 
   polkit->priv->bus = g_bus_get_sync (G_BUS_TYPE_SYSTEM, NULL, &error);
 
@@ -417,7 +427,7 @@ xfpm_polkit_init (XfpmPolkit *polkit)
     goto out;
   }
 
-#ifdef ENABLE_POLKIT
+#ifdef HAVE_POLKIT
   polkit->priv->proxy =
   g_dbus_proxy_new_sync (polkit->priv->bus,
                          G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
@@ -430,14 +440,14 @@ xfpm_polkit_init (XfpmPolkit *polkit)
 
   if (G_LIKELY (polkit->priv->proxy) )
   {
-    g_signal_connect (polkit->priv->proxy, "Changed",
+    g_signal_connect (polkit->priv->proxy, "g-signal",
     G_CALLBACK (xfpm_polkit_changed_cb), polkit);
   }
   else
   {
     g_warning ("Failed to create proxy for 'org.freedesktop.PolicyKit1'");
   }
-#endif /*ENABLE_POLKIT*/
+#endif /*HAVE_POLKIT*/
 
 out:
   ;
@@ -450,7 +460,7 @@ xfpm_polkit_finalize (GObject *object)
 
   polkit = XFPM_POLKIT (object);
 
-#ifdef ENABLE_POLKIT
+#ifdef HAVE_POLKIT
   if ( polkit->priv->proxy )
   {
     g_signal_handlers_disconnect_by_func (polkit->priv->proxy,
@@ -464,7 +474,7 @@ xfpm_polkit_finalize (GObject *object)
     if (polkit->priv->destroy_id != 0 )
       g_source_remove (polkit->priv->destroy_id);
   }
-#endif /*ENABLE_POLKIT*/
+#endif /*HAVE_POLKIT*/
 
 
   if ( polkit->priv->bus )
@@ -494,7 +504,7 @@ xfpm_polkit_get (void)
 gboolean
 xfpm_polkit_check_auth (XfpmPolkit *polkit, const gchar *action_id)
 {
-#ifdef ENABLE_POLKIT
+#ifdef HAVE_POLKIT
   xfpm_polkit_init_data (polkit);
 #endif
   return xfpm_polkit_check_auth_intern (polkit, action_id);
